#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @Author:      thepoy
# @Email:       thepoy@163.com
# @File Name:   viterbi.pyi
# @Created At:  2022-08-03 09:47:47
# @Modified At: 2023-04-07 13:58:22
# @Modified By: thepoy

from typing import List, Tuple
from . import StatesType, StartType, TransType, EmitType

MIN_FLOAT: float
MIN_INF: float

def viterbi(
    obs: str,
    states: StatesType,
    start_p: StartType,
    trans_p: TransType,
    emit_p: EmitType,
) -> Tuple[str, List[Tuple[str, str]]]: ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @Author:      thepoy
# @Email:       thepoy@163.com
# @File Name:   __init__.pyi
# @Created At:  2022-08-03 09:47:47
# @Modified At: 2023-04-07 13:58:12
# @Modified By: thepoy

from typing import List, Pattern, Generator, Dict, Tuple
from io import TextIOWrapper

TransType = Dict[Tuple[str, str], Dict[Tuple[str, str], float]]
StartType = Dict[Tuple[str, str], float]
EmitType = Dict[Tuple[str, str], Dict[str, float]]
StatesType = Dict[str, Tuple[Tuple[str, str], ...]]

PROB_START_P: str
PROB_TRANS_P: str
PROB_EMIT_P: str
CHAR_STATE_TAB_P: str

re_han_detail: Pattern[str]
re_skip_detail: Pattern[str]
re_han_internal: Pattern[str]
re_skip_internal: Pattern[str]

re_eng: Pattern[str]
re_num: Pattern[str]

re_eng1: Pattern[str]

class pair(object):
    word: str
    flag: str

    def __init__(self, word: str, flag: str) -> None: ...
    def encode(self, arg: str) -> bytes: ...

class POSTokenizer(object):
    def initialize(self, dictionary: str | None = ...) -> None: ...
    def load_word_tag(self, f: TextIOWrapper) -> None: ...
    def makesure_userdict_loaded(self) -> None: ...
    def cut(self, sentence: str, HMM: bool = ...) -> Generator[pair, None, None]: ...
    def lcut(self, sentence: str, HMM: bool = ...) -> List[pair]: ...

dt: POSTokenizer

initialize = dt.initialize

def cut(
    sentence: str, HMM: bool = ..., use_paddle: bool = ...
) -> Generator[pair, None, None]: ...
def lcut(sentence: str, HMM: bool = ..., use_paddle: bool = ...) -> List[pair]: ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @Author:      thepoy
# @Email:       thepoy@163.com
# @File Name:   textrank.pyi
# @Created At:  2022-08-03 09:47:47
# @Modified At: 2023-04-07 14:00:55
# @Modified By: thepoy

from collections import defaultdict
from jieba import Tokenizer
from jieba.posseg import pair
from .tfidf import KeywordExtractor
from typing import List, Set, Tuple

class UndirectWeightedGraph:
    d: float
    graph: defaultdict[float, List[Tuple[float, float, float]]]

    def addEdge(self, start: float, end: float, weight: float) -> None: ...
    def rank(self) -> defaultdict[float, float]: ...

class TextRank(KeywordExtractor):
    tokenizer: Tokenizer
    postokenizer = tokenizer
    stop_words: Set[str]
    pos_filt: frozenset[str]
    span: int

    def pairfilter(self, wp: pair) -> bool: ...
    def textrank(
        self,
        sentence: str,
        topK: int = ...,
        withWeight: bool = ...,
        allowPOS: Tuple[str, ...] = ...,
        withFlag: bool = ...,
    ) -> List[Tuple[str, float] | str]: ...
    def extract_tags(
        self,
        sentence: str,
        topK: int = ...,
        withWeight: bool = ...,
        allowPOS: Tuple[str, ...] = ...,
        withFlag: bool = ...,
    ) -> List[Tuple[str, float] | str]: ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @Author:      thepoy
# @Email:       thepoy@163.com
# @File Name:   __init__.pyi
# @Created At:  2022-08-03 09:47:47
# @Modified At: 2023-04-07 13:57:55
# @Modified By: thepoy

from io import TextIOWrapper
from multiprocessing.pool import Pool
from typing import Dict, List, Tuple, Generator, Callable
from re import Pattern
from threading import RLock

__version__: str
__license__: str

def _get_abs_path(path: str) -> str: ...

DEFAULT_DICT: str | None
DEFAULT_DICT_NAME: str

DICT_WRITING: Dict[str, RLock]

pool: Pool | None

re_userdict: Pattern[str]
re_eng: Pattern[str]
re_han_default: Pattern[str]
re_skip_default: Pattern[str]

DAGType = Dict[int, List[int]]
DictFileType = str | TextIOWrapper

def setLogLevel(log_level: int) -> None: ...

class Tokenizer:
    lock: RLock
    dictionary: str
    FREQ: Dict[str, int]
    user_word_tag_tab: Dict[str, str]
    total: int
    initialized: bool
    tmp_dir: str | None
    cache_file: str | None

    @staticmethod
    def gen_pfdict(f: DictFileType) -> Tuple[Dict[str, int], int]: ...
    def initialize(self, dictionary: str | None = ...) -> None: ...
    def check_initialized(self) -> None: ...
    def calc(
        self,
        sentence: str,
        DAG: DAGType,
        route: Dict[int, Tuple[int, int]],
    ) -> None: ...
    def get_DAG(self, sentence: str) -> DAGType: ...
    def cut(
        self,
        sentence: str,
        cut_all: bool = ...,
        HMM: bool = ...,
        use_paddle: bool = ...,
    ) -> Generator[str, None, None]: ...
    def cut_for_search(
        self, sentence: str, HMM: bool = ...
    ) -> Generator[str, None, None]: ...
    def lcut(
        self,
        sentence: str,
        cut_all: bool = ...,
        HMM: bool = ...,
        use_paddle: bool = ...,
    ) -> List[str]: ...
    def lcut_for_search(self, sentence: str, HMM: bool = ...) -> List[str]: ...
    def get_dict_file(self) -> TextIOWrapper: ...
    def load_userdict(self, f: DictFileType) -> None: ...
    def add_word(
        self, word: str, freq: str | int | None = ..., tag: str | None = ...
    ) -> None: ...
    def del_word(self, word: str) -> None: ...
    def suggest_freq(self, segment: str | bytes, tune: bool = ...) -> int: ...
    def tokenize(
        self, unicode_sentence: str, mode: str = ..., HMM: bool = ...
    ) -> Generator[Tuple[str, int, int], None, None]: ...
    def set_dictionary(self, dictionary_path: str) -> None: ...

dt: Tokenizer

cut = dt.cut
get_FREQ: Callable[[str, int | None], int]
add_word = dt.add_word
calc = dt.calc
cut = dt.cut
lcut = dt.lcut
cut_for_search = dt.cut_for_search
lcut_for_search = dt.lcut_for_search
del_word = dt.del_word
get_DAG = dt.get_DAG
get_dict_file = dt.get_dict_file
initialize = dt.initialize
load_userdict = dt.load_userdict
set_dictionary = dt.set_dictionary
suggest_freq = dt.suggest_freq
tokenize = dt.tokenize
user_word_tag_tab = dt.user_word_tag_tab

def enable_parallel(processnum: int | None = ...) -> None: ...
def disable_parallel() -> None: ...



from io import BufferedReader, TextIOWrapper
from typing import Dict, Tuple, Type

check_paddle_install: Dict[str, bool]

default_encoding: str

text_type: Type[str]
string_types: Tuple[Type[str]]


def get_module_res(
    *res: str,
) -> BufferedReader:
    ...


def strdecode(sentence: str | bytes) -> str:
    ...


def resolve_filename(f: str | TextIOWrapper) -> str:
    ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @Author:      thepoy
# @Email:       thepoy@163.com
# @File Name:   prob_trans.pyi
# @Created At:  2022-08-03 09:47:47
# @Modified At: 2023-04-07 13:58:25
# @Modified By: thepoy

from . import TransType

P: TransType



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @Author:      thepoy
# @Email:       thepoy@163.com
# @File Name:   __init__.pyi
# @Created At:  2022-08-03 09:47:47
# @Modified At: 2023-04-10 10:44:24
# @Modified By: thepoy

from .tfidf import TFIDF
from .textrank import TextRank

default_tfidf: TFIDF
default_textrank: TextRank

extract_tags = tfidf = default_tfidf.extract_tags
set_idf_path = default_tfidf.set_idf_path
textrank = default_textrank.extract_tags

def set_stop_words(stop_words_path: str) -> None: ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @Author:      thepoy
# @Email:       thepoy@163.com
# @File Name:   tfidf.pyi
# @Created At:  2022-08-03 09:47:47
# @Modified At: 2023-04-07 14:00:34
# @Modified By: thepoy

from typing import Dict, List, Set, Tuple, Any
from abc import abstractmethod
from jieba import Tokenizer
from jieba.posseg import POSTokenizer

DEFAULT_IDF: str

class KeywordExtractor:
    STOP_WORDS: Set[str]

    def set_stop_words(self, stop_words_path: str) -> None: ...
    @abstractmethod
    def extract_tags(self, *args: Any, **kwargs: Dict[str, Any]) -> Any: ...

class IDFLoader(object):
    path: str
    idf_freq: Dict[str, float]
    median_idf: float

    def __init__(self, idf_path: str | None = ...) -> None: ...
    def set_new_path(self, new_idf_path: str) -> None: ...
    def get_idf(self) -> Tuple[Dict[str, float], float]: ...

class TFIDF(KeywordExtractor):
    tokenizer: Tokenizer
    postokenizer: POSTokenizer
    stop_words: Set[str]
    idf_loader: IDFLoader
    idf_freq: Dict[str, float]
    median_idf: float

    def __init__(self, idf_path: str | None = ...) -> None: ...
    def set_idf_path(self, idf_path: str) -> None: ...
    def extract_tags(
        self,
        sentence: str,
        topK: int = ...,
        withWeight: bool = ...,
        allowPOS: Tuple[str, ...] = ...,
        withFlag: bool = ...,
    ) -> List[Tuple[str, float] | str]: ...
